/*******************************************************************************
 * Copyright (c) 2012 University of Illinois/NCSA.  All rights reserved.
 * 
 *   National Center for Supercomputing Applications (NCSA)
 *   http://www.ncsa.illinois.edu/
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the 
 * "Software"), to deal with the Software without restriction, including 
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of University of Illinois, NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 ******************************************************************************/
package edu.illinois.ncsa.paw.domain;

import javax.persistence.Entity;

import edu.illinois.ncsa.domain.AbstractBean;

/**
 * A marked input, output or parameter exposed on the web.
 * 
 * @author Luigi Marini
 * 
 */
@Entity(name = "MarkedParameter")
public class MarkedParameter extends AbstractBean {

    public enum TYPE {
        INPUT, PARAMETER, OUTPUT
    }

    /** Id of original parameter in workflow description **/
    private String            refId;

    /**
     * Which field in the input configuration this parameter refers to. Useful
     * for when an input widget has multiple fields that get set.
     **/
    private String            inputConfigurationFieldId;

    /** Parameter type **/
    private TYPE              type;

    /** Used for serialization of object */
    private static final long serialVersionUID = 1L;

    public MarkedParameter() {}

    public MarkedParameter(String refId, TYPE type) {
        this.refId = refId;
        this.type = type;
    }

    public String getRefId() {
        return refId;
    }

    public void setRefId(String refId) {
        this.refId = refId;
    }

    public String getType() {
        return type.toString();
    }

    public void setType(String type) {
        this.type = TYPE.valueOf(type);
    }

    public String getInputConfigurationFieldId() {
        return inputConfigurationFieldId;
    }

    public void setInputConfigurationFieldId(String inputConfigurationFieldId) {
        this.inputConfigurationFieldId = inputConfigurationFieldId;
    }

}
